#ifndef BOOST_SIMD_INCLUDE_FUNCTIONS_SIMD_NEGIF_HPP_INCLUDED
#define BOOST_SIMD_INCLUDE_FUNCTIONS_SIMD_NEGIF_HPP_INCLUDED

#include <boost/simd/boolean/include/functions/simd/negif.hpp>

#endif
